@@ -1,12 +1,18 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Any, Iterator, List, Sequence, cast, overload
+from typing import TYPE_CHECKING, Any, Iterator, Sequence, cast, overload
 
-from cognite.client import utils
 from cognite.client._api_client import APIClient
 from cognite.client._constants import DEFAULT_LIMIT_READ
 from cognite.client.data_classes import Database, DatabaseList, Row, RowList, Table, TableList
-from cognite.client.utils._auxiliary import is_unlimited, local_import
+from cognite.client.utils._auxiliary import (
+    assert_type,
+    interpolate_and_url_encode,
+    is_unlimited,
+    local_import,
+    split_into_chunks,
+)
+from cognite.client.utils._concurrency import execute_tasks
 from cognite.client.utils._identifier import Identifier
 
 if TYPE_CHECKING:
@@ -78,7 +84,7 @@ class RawDatabasesAPI(APIClient):
                 >>> c = CogniteClient()
                 >>> res = c.raw.databases.create("db1")
         """
-        utils._auxiliary.assert_type(name, "name", [str, Sequence])
+        assert_type(name, "name", [str, Sequence])
         if isinstance(name, str):
             items: dict[str, Any] | list[dict[str, Any]] = {"name": name}
         else:
@@ -100,16 +106,16 @@ class RawDatabasesAPI(APIClient):
                 >>> c = CogniteClient()
                 >>> c.raw.databases.delete(["db1", "db2"])
         """
-        utils._auxiliary.assert_type(name, "name", [str, Sequence])
+        assert_type(name, "name", [str, Sequence])
         if isinstance(name, str):
             name = [name]
         items = [{"name": n} for n in name]
-        chunks = utils._auxiliary.split_into_chunks(items, self._DELETE_LIMIT)
+        chunks = split_into_chunks(items, self._DELETE_LIMIT)
         tasks = [
             {"url_path": self._RESOURCE_PATH + "/delete", "json": {"items": chunk, "recursive": recursive}}
             for chunk in chunks
         ]
-        summary = utils._concurrency.execute_tasks(self._post, tasks, max_workers=self._config.max_workers)
+        summary = execute_tasks(self._post, tasks, max_workers=self._config.max_workers)
         summary.raise_compound_exception_if_failed_tasks(
             task_unwrap_fn=lambda task: task["json"]["items"], task_list_element_unwrap_fn=lambda el: el["name"]
         )
@@ -169,7 +175,7 @@ class RawTablesAPI(APIClient):
         table_iterator = self._list_generator(
             list_cls=TableList,
             resource_cls=Table,
-            resource_path=utils._auxiliary.interpolate_and_url_encode(self._RESOURCE_PATH, db_name),
+            resource_path=interpolate_and_url_encode(self._RESOURCE_PATH, db_name),
             chunk_size=chunk_size,
             method="GET",
             limit=limit,
@@ -202,7 +208,7 @@ class RawTablesAPI(APIClient):
                 >>> c = CogniteClient()
                 >>> res = c.raw.tables.create("db1", "table1")
         """
-        utils._auxiliary.assert_type(name, "name", [str, Sequence])
+        assert_type(name, "name", [str, Sequence])
         if isinstance(name, str):
             items: dict[str, Any] | list[dict[str, Any]] = {"name": name}
         else:
@@ -210,7 +216,7 @@ class RawTablesAPI(APIClient):
         tb = self._create_multiple(
             list_cls=TableList,
             resource_cls=Table,
-            resource_path=utils._auxiliary.interpolate_and_url_encode(self._RESOURCE_PATH, db_name),
+            resource_path=interpolate_and_url_encode(self._RESOURCE_PATH, db_name),
             items=items,
         )
         return self._set_db_name_on_tables(tb, db_name)
@@ -230,19 +236,19 @@ class RawTablesAPI(APIClient):
                 >>> c = CogniteClient()
                 >>> res = c.raw.tables.delete("db1", ["table1", "table2"])
         """
-        utils._auxiliary.assert_type(name, "name", [str, Sequence])
+        assert_type(name, "name", [str, Sequence])
         if isinstance(name, str):
             name = [name]
         items = [{"name": n} for n in name]
-        chunks = utils._auxiliary.split_into_chunks(items, self._DELETE_LIMIT)
+        chunks = split_into_chunks(items, self._DELETE_LIMIT)
         tasks = [
             {
-                "url_path": utils._auxiliary.interpolate_and_url_encode(self._RESOURCE_PATH, db_name) + "/delete",
+                "url_path": interpolate_and_url_encode(self._RESOURCE_PATH, db_name) + "/delete",
                 "json": {"items": chunk},
             }
             for chunk in chunks
         ]
-        summary = utils._concurrency.execute_tasks(self._post, tasks, max_workers=self._config.max_workers)
+        summary = execute_tasks(self._post, tasks, max_workers=self._config.max_workers)
         summary.raise_compound_exception_if_failed_tasks(
             task_unwrap_fn=lambda task: task["json"]["items"], task_list_element_unwrap_fn=lambda el: el["name"]
         )
@@ -298,7 +304,7 @@ class RawTablesAPI(APIClient):
         tb = self._list(
             list_cls=TableList,
             resource_cls=Table,
-            resource_path=utils._auxiliary.interpolate_and_url_encode(self._RESOURCE_PATH, db_name),
+            resource_path=interpolate_and_url_encode(self._RESOURCE_PATH, db_name),
             method="GET",
             limit=limit,
         )
@@ -342,7 +348,7 @@ class RawRowsAPI(APIClient):
         return self._list_generator(
             list_cls=RowList,
             resource_cls=Row,
-            resource_path=utils._auxiliary.interpolate_and_url_encode(self._RESOURCE_PATH, db_name, table_name),
+            resource_path=interpolate_and_url_encode(self._RESOURCE_PATH, db_name, table_name),
             chunk_size=chunk_size,
             method="GET",
             limit=limit,
@@ -377,13 +383,13 @@ class RawRowsAPI(APIClient):
 
         tasks = [
             {
-                "url_path": utils._auxiliary.interpolate_and_url_encode(self._RESOURCE_PATH, db_name, table_name),
+                "url_path": interpolate_and_url_encode(self._RESOURCE_PATH, db_name, table_name),
                 "json": {"items": chunk},
                 "params": {"ensureParent": ensure_parent},
             }
             for chunk in chunks
         ]
-        summary = utils._concurrency.execute_tasks(self._post, tasks, max_workers=self._config.max_workers)
+        summary = execute_tasks(self._post, tasks, max_workers=self._config.max_workers)
         summary.raise_compound_exception_if_failed_tasks(
             task_unwrap_fn=lambda task: task["json"]["items"], task_list_element_unwrap_fn=lambda row: row.get("key")
         )
@@ -415,7 +421,7 @@ class RawRowsAPI(APIClient):
         self.insert(db_name=db_name, table_name=table_name, row=rows, ensure_parent=ensure_parent)
 
     def _process_row_input(self, row: Sequence[Row] | Row | dict) -> list[list[dict]]:
-        utils._auxiliary.assert_type(row, "row", [Sequence, dict, Row])
+        assert_type(row, "row", [Sequence, dict, Row])
         rows = []
         if isinstance(row, dict):
             for key, columns in row.items():
@@ -428,7 +434,7 @@ class RawRowsAPI(APIClient):
                     raise TypeError("list elements must be Row objects.")
         elif isinstance(row, Row):
             rows.append(row.dump(camel_case=True))
-        return utils._auxiliary.split_into_chunks(rows, self._CREATE_LIMIT)
+        return split_into_chunks(rows, self._CREATE_LIMIT)
 
     def delete(self, db_name: str, table_name: str, key: str | Sequence[str]) -> None:
         """`Delete rows from a table. <https://developer.cognite.com/api#tag/Raw/operation/deleteRows>`_
@@ -447,22 +453,21 @@ class RawRowsAPI(APIClient):
                 >>> keys_to_delete = ["k1", "k2", "k3"]
                 >>> c.raw.rows.delete("db1", "table1", keys_to_delete)
         """
-        utils._auxiliary.assert_type(key, "key", [str, Sequence])
+        assert_type(key, "key", [str, Sequence])
         if isinstance(key, str):
             key = [key]
         items = [{"key": k} for k in key]
-        chunks = utils._auxiliary.split_into_chunks(items, self._DELETE_LIMIT)
+        chunks = split_into_chunks(items, self._DELETE_LIMIT)
         tasks = [
             (
                 {
-                    "url_path": utils._auxiliary.interpolate_and_url_encode(self._RESOURCE_PATH, db_name, table_name)
-                    + "/delete",
+                    "url_path": interpolate_and_url_encode(self._RESOURCE_PATH, db_name, table_name) + "/delete",
                     "json": {"items": chunk},
                 }
             )
             for chunk in chunks
         ]
-        summary = utils._concurrency.execute_tasks(self._post, tasks, max_workers=self._config.max_workers)
+        summary = execute_tasks(self._post, tasks, max_workers=self._config.max_workers)
         summary.raise_compound_exception_if_failed_tasks(
             task_unwrap_fn=lambda task: task["json"]["items"], task_list_element_unwrap_fn=lambda el: el["key"]
         )
@@ -488,19 +493,19 @@ class RawRowsAPI(APIClient):
         """
         return self._retrieve(
             cls=Row,
-            resource_path=utils._auxiliary.interpolate_and_url_encode(self._RESOURCE_PATH, db_name, table_name),
+            resource_path=interpolate_and_url_encode(self._RESOURCE_PATH, db_name, table_name),
             identifier=Identifier(key),
         )
 
     def _make_columns_param(self, columns: list[str] | None) -> str | None:
         if columns is None:
             return None
-        if not isinstance(columns, List):
+        if not isinstance(columns, list):
             raise ValueError("Expected a list for argument columns")
         if len(columns) == 0:
             return ","
         else:
-            return ",".join([str(x) for x in columns])
+            return ",".join(str(x) for x in columns)
 
     def retrieve_dataframe(
         self,
@@ -586,9 +591,7 @@ class RawRowsAPI(APIClient):
         """
         if is_unlimited(limit):
             cursors = self._get(
-                url_path=utils._auxiliary.interpolate_and_url_encode(
-                    "/raw/dbs/{}/tables/{}/cursors", db_name, table_name
-                ),
+                url_path=interpolate_and_url_encode("/raw/dbs/{}/tables/{}/cursors", db_name, table_name),
                 params={
                     "minLastUpdatedTime": min_last_updated_time,
                     "maxLastUpdatedTime": max_last_updated_time,
@@ -601,7 +604,7 @@ class RawRowsAPI(APIClient):
             dict(
                 list_cls=RowList,
                 resource_cls=Row,
-                resource_path=utils._auxiliary.interpolate_and_url_encode(self._RESOURCE_PATH, db_name, table_name),
+                resource_path=interpolate_and_url_encode(self._RESOURCE_PATH, db_name, table_name),
                 method="GET",
                 filter={
                     "columns": self._make_columns_param(columns),
@@ -613,7 +616,7 @@ class RawRowsAPI(APIClient):
             )
             for cursor in cursors
         ]
-        summary = utils._concurrency.execute_tasks(self._list, tasks, max_workers=self._config.max_workers)
-        if summary.exceptions:
-            raise summary.exceptions[0]
+        summary = execute_tasks(self._list, tasks, max_workers=self._config.max_workers)
+        summary.raise_first_encountered_exception()
+
         return RowList(summary.joined_results())
