@@ -3,12 +3,12 @@ from __future__ import annotations
 import copy
 from typing import TYPE_CHECKING, Any, Iterator, Literal, Sequence, cast, overload
 
-from cognite.client import utils
 from cognite.client._api_client import APIClient
 from cognite.client._constants import DEFAULT_LIMIT_READ
 from cognite.client.data_classes import Relationship, RelationshipFilter, RelationshipList, RelationshipUpdate
 from cognite.client.data_classes.labels import LabelFilter
-from cognite.client.utils._auxiliary import is_unlimited
+from cognite.client.utils._auxiliary import assert_type, is_unlimited
+from cognite.client.utils._concurrency import execute_tasks
 from cognite.client.utils._identifier import IdentifierSequence
 from cognite.client.utils._validation import process_data_set_ids
 
@@ -85,12 +85,12 @@ class RelationshipsAPI(APIClient):
             target_types (Sequence[str] | None): Include relationships that have any of these values in their target Type field
             data_set_ids (int | Sequence[int] | None): Return only relationships in the specified data set(s) with this id / these ids.
             data_set_external_ids (str | Sequence[str] | None): Return only relationships in the specified data set(s) with this external id / these external ids.
-            start_time (dict[str, int] | None): Range between two timestamps, minimum and maximum milli seconds (inclusive)
-            end_time (dict[str, int] | None): Range between two timestamps, minimum and maximum milli seconds (inclusive)
+            start_time (dict[str, int] | None): Range between two timestamps, minimum and maximum milliseconds (inclusive)
+            end_time (dict[str, int] | None): Range between two timestamps, minimum and maximum milliseconds (inclusive)
             confidence (dict[str, int] | None): Range to filter the field for (inclusive).
             last_updated_time (dict[str, int] | None): Range to filter the field for (inclusive).
             created_time (dict[str, int] | None): Range to filter the field for (inclusive).
-            active_at_time (dict[str, int] | None): Limits results to those active at any point within the given time range, i.e. if there is any overlap in the intervals [activeAtTime.min, activeAtTime.max] and [startTime, endTime], where both intervals are inclusive. If a relationship does not have a startTime, it is regarded as active from the begining of time by this filter. If it does not have an endTime is will be regarded as active until the end of time. Similarly, if a min is not supplied to the filter, the min will be implicitly set to the beginning of time, and if a max is not supplied, the max will be implicitly set to the end of time.
+            active_at_time (dict[str, int] | None): Limits results to those active at any point within the given time range, i.e. if there is any overlap in the intervals [activeAtTime.min, activeAtTime.max] and [startTime, endTime], where both intervals are inclusive. If a relationship does not have a startTime, it is regarded as active from the beginning of time by this filter. If it does not have an endTime is will be regarded as active until the end of time. Similarly, if a min is not supplied to the filter, the min will be implicitly set to the beginning of time, and if a max is not supplied, the max will be implicitly set to the end of time.
             labels (LabelFilter | None): Return only the resource matching the specified label constraints.
             limit (int | None): No description.
             fetch_resources (bool): No description.
@@ -231,12 +231,12 @@ class RelationshipsAPI(APIClient):
             target_types (Sequence[str] | None): Include relationships that have any of these values in their target Type field
             data_set_ids (int | Sequence[int] | None): Return only relationships in the specified data set(s) with this id / these ids.
             data_set_external_ids (str | Sequence[str] | None): Return only relationships in the specified data set(s) with this external id / these external ids.
-            start_time (dict[str, int] | None): Range between two timestamps, minimum and maximum milli seconds (inclusive)
-            end_time (dict[str, int] | None): Range between two timestamps, minimum and maximum milli seconds (inclusive)
+            start_time (dict[str, int] | None): Range between two timestamps, minimum and maximum milliseconds (inclusive)
+            end_time (dict[str, int] | None): Range between two timestamps, minimum and maximum milliseconds (inclusive)
             confidence (dict[str, int] | None): Range to filter the field for (inclusive).
             last_updated_time (dict[str, int] | None): Range to filter the field for (inclusive).
             created_time (dict[str, int] | None): Range to filter the field for (inclusive).
-            active_at_time (dict[str, int] | None): Limits results to those active at any point within the given time range, i.e. if there is any overlap in the intervals [activeAtTime.min, activeAtTime.max] and [startTime, endTime], where both intervals are inclusive. If a relationship does not have a startTime, it is regarded as active from the begining of time by this filter. If it does not have an endTime is will be regarded as active until the end of time. Similarly, if a min is not supplied to the filter, the min will be implicitly set to the beginning of time, and if a max is not supplied, the max will be implicitly set to the end of time.
+            active_at_time (dict[str, int] | None): Limits results to those active at any point within the given time range, i.e. if there is any overlap in the intervals [activeAtTime.min, activeAtTime.max] and [startTime, endTime], where both intervals are inclusive. If a relationship does not have a startTime, it is regarded as active from the beginning of time by this filter. If it does not have an endTime is will be regarded as active until the end of time. Similarly, if a min is not supplied to the filter, the min will be implicitly set to the beginning of time, and if a max is not supplied, the max will be implicitly set to the end of time.
             labels (LabelFilter | None): Return only the resource matching the specified label constraints.
             limit (int | None): Maximum number of relationships to return. Defaults to 25. Set to -1, float("inf") or None to return all items.
             partitions (int | None): Retrieve relationships in parallel using this number of workers. Also requires `limit=None` to be passed.
@@ -298,7 +298,7 @@ class RelationshipsAPI(APIClient):
                         task_filter["sourceExternalIds"] = source_external_id_list[si : si + self._LIST_SUBQUERY_LIMIT]
                     tasks.append((task_filter,))
 
-            tasks_summary = utils._concurrency.execute_tasks(
+            tasks_summary = execute_tasks(
                 lambda filter: self._list(
                     list_cls=RelationshipList,
                     resource_cls=Relationship,
@@ -311,8 +311,8 @@ class RelationshipsAPI(APIClient):
                 tasks,
                 max_workers=self._config.max_workers,
             )
-            if tasks_summary.exceptions:
-                raise tasks_summary.exceptions[0]
+            tasks_summary.raise_first_encountered_exception()
+
             return RelationshipList(tasks_summary.joined_results())
         return self._list(
             list_cls=RelationshipList,
@@ -363,7 +363,7 @@ class RelationshipsAPI(APIClient):
                 ... )
                 >>> res = c.relationships.create([flowrel1,flowrel2])
         """
-        utils._auxiliary.assert_type(relationship, "relationship", [Relationship, Sequence])
+        assert_type(relationship, "relationship", [Relationship, Sequence])
         if isinstance(relationship, Sequence):
             relationship = [r._validate_resource_types() for r in relationship]
         else:
