@@ -7,7 +7,6 @@ from typing import Sequence as SequenceType
 
 from typing_extensions import TypeAlias
 
-from cognite.client import utils
 from cognite.client._api_client import APIClient
 from cognite.client._constants import DEFAULT_LIMIT_READ
 from cognite.client.data_classes import (
@@ -24,9 +23,11 @@ from cognite.client.data_classes.aggregations import AggregationFilter, UniqueRe
 from cognite.client.data_classes.filters import Filter, _validate_filter
 from cognite.client.data_classes.sequences import SequenceProperty, SequenceSort, SortableSequenceProperty
 from cognite.client.data_classes.shared import TimestampRange
+from cognite.client.utils._auxiliary import assert_type
+from cognite.client.utils._concurrency import execute_tasks
 from cognite.client.utils._identifier import Identifier, IdentifierSequence
 from cognite.client.utils._text import convert_all_keys_to_camel_case
-from cognite.client.utils._validation import process_asset_subtree_ids, process_data_set_ids
+from cognite.client.utils._validation import prepare_filter_sort, process_asset_subtree_ids, process_data_set_ids
 
 if TYPE_CHECKING:
     import pandas
@@ -225,7 +226,7 @@ class SequencesAPI(APIClient):
 
         Args:
             advanced_filter (Filter | dict | None): The filter to narrow down the sequences to count.
-            filter (SequenceFilter | dict | None): The filter to narrow down sequences to count requirering exact match.
+            filter (SequenceFilter | dict | None): The filter to narrow down sequences to count requiring exact match.
 
         Returns:
             int: The number of sequences matching the specified filters and search.
@@ -269,7 +270,7 @@ class SequencesAPI(APIClient):
             property (SequenceProperty | str | list[str]): The property to count the cardinality of.
             advanced_filter (Filter | dict | None): The filter to narrow down the sequences to count cardinality.
             aggregate_filter (AggregationFilter | dict | None): The filter to apply to the resulting buckets.
-            filter (SequenceFilter | dict | None): The filter to narrow down the sequences  to count requirering exact match.
+            filter (SequenceFilter | dict | None): The filter to narrow down the sequences  to count requiring exact match.
 
         Returns:
             int: The number of properties matching the specified filters and search.
@@ -320,7 +321,7 @@ class SequencesAPI(APIClient):
             path (SequenceProperty | str | list[str]): The scope in every document to aggregate properties. The only value allowed now is ["metadata"]. It means to aggregate only metadata properties (aka keys).
             advanced_filter (Filter | dict | None): The filter to narrow down the sequences to count cardinality.
             aggregate_filter (AggregationFilter | dict | None): The filter to apply to the resulting buckets.
-            filter (SequenceFilter | dict | None): The filter to narrow down the sequences  to count requirering exact match.
+            filter (SequenceFilter | dict | None): The filter to narrow down the sequences  to count requiring exact match.
 
         Returns:
             int: The number of properties matching the specified filters and search.
@@ -357,7 +358,7 @@ class SequencesAPI(APIClient):
             property (SequenceProperty | str | list[str]): The property to group by.
             advanced_filter (Filter | dict | None): The filter to narrow down the sequences to count cardinality.
             aggregate_filter (AggregationFilter | dict | None): The filter to apply to the resulting buckets.
-            filter (SequenceFilter | dict | None): The filter to narrow down the sequences to count requirering exact match.
+            filter (SequenceFilter | dict | None): The filter to narrow down the sequences to count requiring exact match.
 
         Returns:
             UniqueResultList: List of unique values of sequences matching the specified filters and search.
@@ -428,7 +429,7 @@ class SequencesAPI(APIClient):
             path (SequenceProperty | str | list[str]): The scope in every document to aggregate properties. The only value allowed now is ["metadata"]. It means to aggregate only metadata properties (aka keys).
             advanced_filter (Filter | dict | None): The filter to narrow down the sequences to count cardinality.
             aggregate_filter (AggregationFilter | dict | None): The filter to apply to the resulting buckets.
-            filter (SequenceFilter | dict | None): The filter to narrow down the sequences to count requirering exact match.
+            filter (SequenceFilter | dict | None): The filter to narrow down the sequences to count requiring exact match.
 
         Returns:
             UniqueResultList: List of unique values of sequences matching the specified filters and search.
@@ -486,7 +487,7 @@ class SequencesAPI(APIClient):
                 >>> seq2 = c.sequences.create(Sequence(external_id="my_copied_sequence", columns=seq.columns))
 
         """
-        utils._auxiliary.assert_type(sequence, "sequences", [SequenceType, Sequence])
+        assert_type(sequence, "sequences", [SequenceType, Sequence])
         if isinstance(sequence, SequenceType):
             sequence = [self._clean_columns(seq) for seq in sequence]
         else:
@@ -738,7 +739,7 @@ class SequencesAPI(APIClient):
 
         Examples:
 
-            Find all sequences with asset id '123' and metadata key 'type' equals 'efficency' and
+            Find all sequences with asset id '123' and metadata key 'type' equals 'efficiency' and
             return them sorted by created time:
 
                 >>> from cognite.client import CogniteClient
@@ -752,7 +753,7 @@ class SequencesAPI(APIClient):
             Note that you can check the API documentation above to see which properties you can filter on
             with which filters.
 
-            To make it easier to avoid spelling mistakes and easiser to look up available properties
+            To make it easier to avoid spelling mistakes and easier to look up available properties
             for filtering and sorting, you can also use the `SequenceProperty` and `SortableSequenceProperty` enums.
 
                 >>> from cognite.client import CogniteClient
@@ -761,16 +762,12 @@ class SequencesAPI(APIClient):
                 >>> c = CogniteClient()
                 >>> f = filters
                 >>> is_asset = f.Equals(SequenceProperty.asset_id, 123)
-                >>> is_efficency = f.Equals(SequenceProperty.metadata_key("type"), "efficiency")
-                >>> res = c.time_series.filter(filter=f.And(is_asset, is_efficency),
+                >>> is_efficiency = f.Equals(SequenceProperty.metadata_key("type"), "efficiency")
+                >>> res = c.time_series.filter(filter=f.And(is_asset, is_efficiency),
                 ...                            sort=SortableSequenceProperty.created_time)
 
         """
         self._validate_filter(filter)
-        if sort is None:
-            sort = []
-        elif not isinstance(sort, list):
-            sort = [sort]
 
         return self._list(
             list_cls=SequenceList,
@@ -778,7 +775,7 @@ class SequencesAPI(APIClient):
             method="POST",
             limit=limit,
             advanced_filter=filter.dump(camel_case=True) if isinstance(filter, Filter) else filter,
-            sort=[SequenceSort.load(item).dump(camel_case=True) for item in sort],
+            sort=prepare_filter_sort(sort, SequenceSort),
             api_subversion="beta",
         )
 
@@ -939,7 +936,7 @@ class SequencesDataAPI(APIClient):
 
         row_objs = [{"rows": all_rows[i : i + rows_per_request]} for i in range(0, len(all_rows), rows_per_request)]
         tasks = [({**base_obj, **rows},) for rows in row_objs]
-        summary = utils._concurrency.execute_tasks(self._insert_data, tasks, max_workers=self._config.max_workers)
+        summary = execute_tasks(self._insert_data, tasks, max_workers=self._config.max_workers)
         summary.raise_compound_exception_if_failed_tasks()
 
     def insert_dataframe(
@@ -1059,11 +1056,8 @@ class SequencesDataAPI(APIClient):
                 id=post_obj.get("id"), external_id=post_obj.get("externalId"), rows=seqdata, columns=columns
             )
 
-        tasks_summary = utils._concurrency.execute_tasks(
-            _fetch_sequence, [(x,) for x in post_objs], max_workers=self._config.max_workers
-        )
-        if tasks_summary.exceptions:
-            raise tasks_summary.exceptions[0]
+        tasks_summary = execute_tasks(_fetch_sequence, [(x,) for x in post_objs], max_workers=self._config.max_workers)
+        tasks_summary.raise_first_encountered_exception()
         results = tasks_summary.joined_results()
         if len(post_objs) == 1:
             return results[0]
@@ -1082,7 +1076,7 @@ class SequencesDataAPI(APIClient):
         Args:
             id (int | None): Id or list of ids.
             external_id (str | None): External id or list of external ids.
-            column_external_ids (SequenceType[str] | None): (optional, SequenceType[str]): external ids of columns to include. Omitting wil return all columns.
+            column_external_ids (SequenceType[str] | None): (optional, SequenceType[str]): external ids of columns to include. Omitting will return all columns.
             before (int | None): (optional, int): Get latest datapoint before this row number.
 
         Returns:
