@@ -19,8 +19,9 @@ from cognite.client.data_classes import (
 from cognite.client.data_classes.aggregations import AggregationFilter, UniqueResultList
 from cognite.client.data_classes.filters import Filter, _validate_filter
 from cognite.client.data_classes.time_series import SortableTimeSeriesProperty, TimeSeriesProperty, TimeSeriesSort
+from cognite.client.utils._experimental import FeaturePreviewWarning
 from cognite.client.utils._identifier import IdentifierSequence
-from cognite.client.utils._validation import process_asset_subtree_ids, process_data_set_ids
+from cognite.client.utils._validation import prepare_filter_sort, process_asset_subtree_ids, process_data_set_ids
 
 if TYPE_CHECKING:
     from cognite.client import CogniteClient
@@ -59,12 +60,15 @@ class TimeSeriesAPI(APIClient):
         super().__init__(config, api_version, cognite_client)
         self.data = DatapointsAPI(config, api_version, cognite_client)
         self.subscriptions = DatapointsSubscriptionAPI(config, api_version, cognite_client)
+        self._unit_warning = FeaturePreviewWarning("beta", "alpha", "Timeseries Unit External ID")
 
     def __call__(
         self,
         chunk_size: int | None = None,
         name: str | None = None,
         unit: str | None = None,
+        unit_external_id: str | None = None,
+        unit_quantity: str | None = None,
         is_string: bool | None = None,
         is_step: bool | None = None,
         asset_ids: Sequence[int] | None = None,
@@ -88,6 +92,8 @@ class TimeSeriesAPI(APIClient):
             chunk_size (int | None): Number of time series to return in each chunk. Defaults to yielding one time series a time.
             name (str | None): Name of the time series. Often referred to as tag.
             unit (str | None): Unit of the time series.
+            unit_external_id (str | None): Filter on unit external ID.
+            unit_quantity (str | None): Filter on unit quantity.
             is_string (bool | None): Whether the time series is an string time series.
             is_step (bool | None): Whether the time series is a step (piecewise constant) time series.
             asset_ids (Sequence[int] | None): List time series related to these assets.
@@ -112,6 +118,8 @@ class TimeSeriesAPI(APIClient):
         filter = TimeSeriesFilter(
             name=name,
             unit=unit,
+            unit_external_id=unit_external_id,
+            unit_quantity=unit_quantity,
             is_step=is_step,
             is_string=is_string,
             asset_ids=asset_ids,
@@ -122,15 +130,19 @@ class TimeSeriesAPI(APIClient):
             data_set_ids=data_set_ids_processed,
             last_updated_time=last_updated_time,
             external_id_prefix=external_id_prefix,
-        ).dump(camel_case=True)
+        )
+
+        api_subversion = self._get_api_subversion(filter.unit_external_id, filter.unit_quantity)
+
         return self._list_generator(
             list_cls=TimeSeriesList,
             resource_cls=TimeSeries,
             method="POST",
             chunk_size=chunk_size,
-            filter=filter,
+            filter=filter.dump(camel_case=True),
             limit=limit,
             partitions=partitions,
+            api_subversion=api_subversion,
         )
 
     def __iter__(self) -> Iterator[TimeSeries]:
@@ -168,7 +180,14 @@ class TimeSeriesAPI(APIClient):
                 >>> res = c.time_series.retrieve(external_id="1")
         """
         identifiers = IdentifierSequence.load(ids=id, external_ids=external_id).as_singleton()
-        return self._retrieve_multiple(list_cls=TimeSeriesList, resource_cls=TimeSeries, identifiers=identifiers)
+
+        return self._retrieve_multiple(
+            list_cls=TimeSeriesList,
+            resource_cls=TimeSeries,
+            identifiers=identifiers,
+            # Unit external id is only supported in beta, this can be removed when it is released in GA.
+            api_subversion="beta",
+        )
 
     def retrieve_multiple(
         self,
@@ -206,6 +225,8 @@ class TimeSeriesAPI(APIClient):
             resource_cls=TimeSeries,
             identifiers=identifiers,
             ignore_unknown_ids=ignore_unknown_ids,
+            # Unit external id is only supported in beta, this can be removed when it is released in GA.
+            api_subversion="beta",
         )
 
     def aggregate(self, filter: TimeSeriesFilter | dict | None = None) -> list[TimeSeriesAggregate]:
@@ -237,7 +258,7 @@ class TimeSeriesAPI(APIClient):
 
         Args:
             advanced_filter (Filter | dict | None): The filter to narrow down the time series to count.
-            filter (TimeSeriesFilter | dict | None): The filter to narrow down time series to count requirering exact match.
+            filter (TimeSeriesFilter | dict | None): The filter to narrow down time series to count requiring exact match.
 
         Returns:
             int: The number of time series matching the specified filters and search.
@@ -281,7 +302,7 @@ class TimeSeriesAPI(APIClient):
             property (TimeSeriesProperty | str | list[str]): The property to count the cardinality of.
             advanced_filter (Filter | dict | None): The filter to narrow down the time series to count cardinality.
             aggregate_filter (AggregationFilter | dict | None): The filter to apply to the resulting buckets.
-            filter (TimeSeriesFilter | dict | None): The filter to narrow down the time series to count requirering exact match.
+            filter (TimeSeriesFilter | dict | None): The filter to narrow down the time series to count requiring exact match.
         Returns:
             int: The number of properties matching the specified filters and search.
 
@@ -332,7 +353,7 @@ class TimeSeriesAPI(APIClient):
             path (TimeSeriesProperty | str | list[str]): The scope in every document to aggregate properties. The only value allowed now is ["metadata"]. It means to aggregate only metadata properties (aka keys).
             advanced_filter (Filter | dict | None): The filter to narrow down the time series to count cardinality.
             aggregate_filter (AggregationFilter | dict | None): The filter to apply to the resulting buckets.
-            filter (TimeSeriesFilter | dict | None): The filter to narrow down the time series to count requirering exact match.
+            filter (TimeSeriesFilter | dict | None): The filter to narrow down the time series to count requiring exact match.
         Returns:
             int: The number of properties matching the specified filters and search.
 
@@ -368,7 +389,7 @@ class TimeSeriesAPI(APIClient):
             property (TimeSeriesProperty | str | list[str]): The property to group by.
             advanced_filter (Filter | dict | None): The filter to narrow down the time series to count cardinality.
             aggregate_filter (AggregationFilter | dict | None): The filter to apply to the resulting buckets.
-            filter (TimeSeriesFilter | dict | None): The filter to narrow down the time series to count requirering exact match.
+            filter (TimeSeriesFilter | dict | None): The filter to narrow down the time series to count requiring exact match.
 
         Returns:
             UniqueResultList: List of unique values of time series matching the specified filters and search.
@@ -430,7 +451,7 @@ class TimeSeriesAPI(APIClient):
             path (TimeSeriesProperty | str | list[str]): The scope in every document to aggregate properties. The only value allowed now is ["metadata"]. It means to aggregate only metadata properties (aka keys).
             advanced_filter (Filter | dict | None): The filter to narrow down the time series to count cardinality.
             aggregate_filter (AggregationFilter | dict | None): The filter to apply to the resulting buckets.
-            filter (TimeSeriesFilter | dict | None): The filter to narrow down the time series to count requirering exact match.
+            filter (TimeSeriesFilter | dict | None): The filter to narrow down the time series to count requiring exact match.
 
         Returns:
             UniqueResultList: List of unique values of time series matching the specified filters and search.
@@ -480,7 +501,11 @@ class TimeSeriesAPI(APIClient):
                 >>> c = CogniteClient()
                 >>> ts = c.time_series.create(TimeSeries(name="my ts"))
         """
-        return self._create_multiple(list_cls=TimeSeriesList, resource_cls=TimeSeries, items=time_series)
+        api_subversion = self._get_subapiversion_item(time_series)
+
+        return self._create_multiple(
+            list_cls=TimeSeriesList, resource_cls=TimeSeries, items=time_series, api_subversion=api_subversion
+        )
 
     def delete(
         self,
@@ -546,10 +571,36 @@ class TimeSeriesAPI(APIClient):
                 >>> my_update = TimeSeriesUpdate(id=1).description.set("New description").metadata.add({"key": "value"})
                 >>> res = c.time_series.update(my_update)
         """
+        api_subversion = self._get_subapiversion_item(item)
+
         return self._update_multiple(
-            list_cls=TimeSeriesList, resource_cls=TimeSeries, update_cls=TimeSeriesUpdate, items=item
+            list_cls=TimeSeriesList,
+            resource_cls=TimeSeries,
+            update_cls=TimeSeriesUpdate,
+            items=item,
+            api_subversion=api_subversion,
         )
 
+    def _get_subapiversion_item(
+        self, item: TimeSeries | TimeSeriesUpdate | Sequence[TimeSeries | TimeSeriesUpdate]
+    ) -> str | None:
+        api_subversion: str | None = None
+        if isinstance(item, TimeSeries) and item.unit_external_id:
+            api_subversion = "beta"
+        elif isinstance(item, TimeSeriesUpdate) and "unitExternalId" in item.dump(camel_case=True).get("update", {}):
+            api_subversion = "beta"
+        elif isinstance(item, Sequence) and any(
+            ts.unit_external_id
+            if isinstance(ts, TimeSeries)
+            else "unitExternalId" in ts.dump(camel_case=True).get("update", {})
+            for ts in item
+        ):
+            api_subversion = "beta"
+
+        if api_subversion == "beta":
+            self._unit_warning.warn()
+        return api_subversion
+
     @overload
     def upsert(self, item: Sequence[TimeSeries], mode: Literal["patch", "replace"] = "patch") -> TimeSeriesList:
         ...
@@ -570,6 +621,7 @@ class TimeSeriesAPI(APIClient):
         Args:
             item (TimeSeries | Sequence[TimeSeries]): TimeSeries or list of TimeSeries to upsert.
             mode (Literal["patch", "replace"]): Whether to patch or replace in the case the time series are existing. If you set 'patch', the call will only update fields with non-null values (default). Setting 'replace' will unset any fields that are not specified.
+                Note replace will skip beta properties (unit_external_id), if you want to replace the beta properties you have to use the update method.
 
         Returns:
             TimeSeries | TimeSeriesList: The upserted time series(s).
@@ -586,6 +638,8 @@ class TimeSeriesAPI(APIClient):
                 >>> new_time_series = TimeSeries(external_id="new_timeSeries", description="New timeSeries")
                 >>> res = c.time_series.upsert([existing_time_series, new_time_series], mode="replace")
         """
+        api_subversion = self._get_subapiversion_item(item)
+
         return self._upsert_multiple(
             item,
             list_cls=TimeSeriesList,
@@ -593,6 +647,7 @@ class TimeSeriesAPI(APIClient):
             update_cls=TimeSeriesUpdate,
             input_resource_cls=TimeSeries,
             mode=mode,
+            api_subversion=api_subversion,
         )
 
     def search(
@@ -630,11 +685,20 @@ class TimeSeriesAPI(APIClient):
                 >>> c = CogniteClient()
                 >>> res = c.time_series.search(filter={"asset_ids":[123]})
         """
+
+        if isinstance(filter, TimeSeriesFilter):
+            api_subversion: str | None = self._get_api_subversion(filter.unit_external_id, filter.unit_quantity)
+        elif isinstance(filter, dict):
+            api_subversion = self._get_api_subversion(filter.get("unitExternalId"), filter.get("unitQuantity"))
+        else:
+            api_subversion = None
+
         return self._search(
             list_cls=TimeSeriesList,
             search={"name": name, "description": description, "query": query},
             filter=filter or {},
             limit=limit,
+            api_subversion=api_subversion,
         )
 
     def filter(
@@ -671,7 +735,7 @@ class TimeSeriesAPI(APIClient):
             Note that you can check the API documentation above to see which properties you can filter on
             with which filters.
 
-            To make it easier to avoid spelling mistakes and easiser to look up available properties
+            To make it easier to avoid spelling mistakes and easier to look up available properties
             for filtering and sorting, you can also use the `TimeSeriesProperty` and `SortableTimeSeriesProperty` enums.
 
                 >>> from cognite.client import CogniteClient
@@ -683,10 +747,6 @@ class TimeSeriesAPI(APIClient):
                 >>> res = c.time_series.filter(filter=is_numeric, sort=SortableTimeSeriesProperty.external_id)
         """
         self._validate_filter(filter)
-        if sort is None:
-            sort = []
-        elif not isinstance(sort, list):
-            sort = [sort]
 
         return self._list(
             list_cls=TimeSeriesList,
@@ -694,8 +754,7 @@ class TimeSeriesAPI(APIClient):
             method="POST",
             limit=limit,
             advanced_filter=filter.dump(camel_case=True) if isinstance(filter, Filter) else filter,
-            sort=[TimeSeriesSort.load(item).dump(camel_case=True) for item in sort],
-            api_subversion="beta",
+            sort=prepare_filter_sort(sort, TimeSeriesSort),
         )
 
     def _validate_filter(self, filter: Filter | dict | None) -> None:
@@ -705,6 +764,8 @@ class TimeSeriesAPI(APIClient):
         self,
         name: str | None = None,
         unit: str | None = None,
+        unit_external_id: str | None = None,
+        unit_quantity: str | None = None,
         is_string: bool | None = None,
         is_step: bool | None = None,
         asset_ids: Sequence[int] | None = None,
@@ -727,6 +788,8 @@ class TimeSeriesAPI(APIClient):
         Args:
             name (str | None): Name of the time series. Often referred to as tag.
             unit (str | None): Unit of the time series.
+            unit_external_id (str | None): Filter on unit external ID.
+            unit_quantity (str | None): Filter on unit quantity.
             is_string (bool | None): Whether the time series is an string time series.
             is_step (bool | None): Whether the time series is a step (piecewise constant) time series.
             asset_ids (Sequence[int] | None): List time series related to these assets.
@@ -773,6 +836,8 @@ class TimeSeriesAPI(APIClient):
         filter = TimeSeriesFilter(
             name=name,
             unit=unit,
+            unit_external_id=unit_external_id,
+            unit_quantity=unit_quantity,
             is_step=is_step,
             is_string=is_string,
             asset_ids=asset_ids,
@@ -784,6 +849,9 @@ class TimeSeriesAPI(APIClient):
             last_updated_time=last_updated_time,
             external_id_prefix=external_id_prefix,
         ).dump(camel_case=True)
+
+        api_subversion = self._get_api_subversion(unit_external_id, unit_quantity)
+
         return self._list(
             list_cls=TimeSeriesList,
             resource_cls=TimeSeries,
@@ -791,4 +859,12 @@ class TimeSeriesAPI(APIClient):
             filter=filter,
             limit=limit,
             partitions=partitions,
+            api_subversion=api_subversion,
         )
+
+    def _get_api_subversion(self, unit_external_id: str | None, unit_quantity: str | None) -> str | None:
+        api_subversion: str | None = None
+        if unit_external_id is not None or unit_quantity is not None:
+            api_subversion = "beta"
+            self._unit_warning.warn()
+        return api_subversion
