@@ -26,9 +26,8 @@ from typing import (
 
 from typing_extensions import TypeAlias
 
-from cognite.client import utils
 from cognite.client.exceptions import CogniteMissingClientError
-from cognite.client.utils._auxiliary import fast_dict_load
+from cognite.client.utils._auxiliary import fast_dict_load, json_dump_default, local_import
 from cognite.client.utils._identifier import IdentifierSequence
 from cognite.client.utils._pandas_helpers import convert_nullable_int_cols, notebook_display_with_fallback
 from cognite.client.utils._text import convert_all_keys_to_camel_case, to_camel_case
@@ -51,7 +50,7 @@ def basic_instance_dump(obj: Any, camel_case: bool) -> dict[str, Any]:
 class CogniteResponse:
     def __str__(self) -> str:
         item = convert_time_attributes_to_datetime(self.dump())
-        return json.dumps(item, default=utils._auxiliary.json_dump_default, indent=4)
+        return json.dumps(item, default=json_dump_default, indent=4)
 
     def __repr__(self) -> str:
         return str(self)
@@ -116,7 +115,7 @@ class CogniteResource(_WithClientMixin):
 
     def __str__(self) -> str:
         item = convert_time_attributes_to_datetime(self.dump())
-        return json.dumps(item, default=utils._auxiliary.json_dump_default, indent=4)
+        return json.dumps(item, default=json_dump_default, indent=4)
 
     def dump(self, camel_case: bool = False) -> dict[str, Any]:
         """Dump the instance into a json serializable Python data type.
@@ -153,7 +152,7 @@ class CogniteResource(_WithClientMixin):
             pandas.DataFrame: The dataframe.
         """
         ignore = [] if ignore is None else ignore
-        pd = cast(Any, utils._auxiliary.local_import("pandas"))
+        pd = cast(Any, local_import("pandas"))
         dumped = self.dump(camel_case=camel_case)
 
         for element in ignore:
@@ -164,10 +163,8 @@ class CogniteResource(_WithClientMixin):
                     dumped.update(dumped.pop(key))
                 else:
                     raise AssertionError(f"Could not expand attribute '{key}'")
-        df = pd.DataFrame(columns=["value"])
-        for name, value in dumped.items():
-            df.loc[name] = [value]
-        return df
+
+        return pd.Series(dumped).to_frame(name="value")
 
     def _repr_html_(self) -> str:
         return notebook_display_with_fallback(self)
@@ -239,7 +236,7 @@ class CogniteResourceList(UserList, Generic[T_CogniteResource], _WithClientMixin
 
     def __str__(self) -> str:
         item = convert_time_attributes_to_datetime(self.dump())
-        return json.dumps(item, default=utils._auxiliary.json_dump_default, indent=4)
+        return json.dumps(item, default=json_dump_default, indent=4)
 
     # TODO: We inherit a lot from UserList that we don't actually support...
     def extend(self, other: Collection[Any]) -> None:  # type: ignore [override]
@@ -263,7 +260,7 @@ class CogniteResourceList(UserList, Generic[T_CogniteResource], _WithClientMixin
         return [resource.dump(camel_case) for resource in self.data]
 
     def get(self, id: int | None = None, external_id: str | None = None) -> T_CogniteResource | None:
-        """Get an item from this list by id or exernal_id.
+        """Get an item from this list by id or external_id.
 
         Args:
             id (int | None): The id of the item to get.
@@ -294,7 +291,7 @@ class CogniteResourceList(UserList, Generic[T_CogniteResource], _WithClientMixin
         Returns:
             pandas.DataFrame: The Cognite resource as a dataframe.
         """
-        pd = cast(Any, utils._auxiliary.local_import("pandas"))
+        pd = cast(Any, local_import("pandas"))
         df = pd.DataFrame(self.dump(camel_case=camel_case))
         df = convert_nullable_int_cols(df, camel_case)
 
@@ -331,6 +328,8 @@ class PropertySpec:
     name: str
     is_container: bool = False
     is_nullable: bool = True
+    # Used to skip replace when the value is None
+    is_beta: bool = False
 
 
 class CogniteUpdate:
@@ -343,7 +342,7 @@ class CogniteUpdate:
         return type(self) is type(other) and self.dump() == other.dump()
 
     def __str__(self) -> str:
-        return json.dumps(self.dump(), default=utils._auxiliary.json_dump_default, indent=4)
+        return json.dumps(self.dump(), default=json_dump_default, indent=4)
 
     def __repr__(self) -> str:
         return str(self)
@@ -493,7 +492,7 @@ class CogniteFilter:
 
     def __str__(self) -> str:
         item = convert_time_attributes_to_datetime(self.dump())
-        return json.dumps(item, default=utils._auxiliary.json_dump_default, indent=4)
+        return json.dumps(item, default=json_dump_default, indent=4)
 
     def __repr__(self) -> str:
         return str(self)
@@ -620,7 +619,7 @@ class CogniteSort:
         self.nulls = nulls
 
     def __str__(self) -> str:
-        return json.dumps(self.dump(), default=utils._auxiliary.json_dump_default, indent=4)
+        return json.dumps(self.dump(), default=json_dump_default, indent=4)
 
     def __repr__(self) -> str:
         return str(self)
