@@ -1,8 +1,10 @@
+from __future__ import annotations
+
 import random
 import re
 import string
 from functools import lru_cache
-from typing import Any, Dict, Iterator, Sequence
+from typing import Any, Iterator, Sequence
 
 
 class DrawTables:
@@ -35,15 +37,39 @@ def iterable_to_case(seq: Sequence[str], camel_case: bool) -> Iterator[str]:
         yield from map(to_snake_case, seq)
 
 
-def convert_all_keys_to_camel_case(dct: Dict[str, Any]) -> Dict[str, Any]:
+def convert_all_keys_to_camel_case(dct: dict[str, Any]) -> dict[str, Any]:
     return dict(zip(map(to_camel_case, dct.keys()), dct.values()))
 
 
-def convert_all_keys_to_snake_case(dct: Dict[str, Any]) -> Dict[str, Any]:
+def convert_all_keys_to_camel_case_recursive(dct: dict[str, Any]) -> dict[str, Any]:
+    """Converts all the dictionary keys from snake to camel cases included nested objects.
+    >>> convert_all_keys_to_camel_case_recursive({"my_key": {"my_key": 1}})
+    {'myKey': {'myKey': 1}}
+    """
+    return {
+        to_camel_case(k): (convert_all_keys_to_camel_case_recursive(v) if isinstance(v, dict) else v)
+        for k, v in dct.items()
+    }
+
+
+def convert_all_keys_recursive(dct: dict[str, Any], camel_case: bool = False) -> dict[str, Any]:
+    """Converts all the dictionary keys from snake to camel cases included nested objects.
+    >>> convert_all_keys_recursive({"my_key": {"my_key": 1}}, camel_case=True)
+    {'myKey': {'myKey': 1}}
+    """
+    return {
+        (to_camel_case(k) if camel_case else k): (
+            convert_all_keys_recursive(v, camel_case) if isinstance(v, dict) else v
+        )
+        for k, v in dct.items()
+    }
+
+
+def convert_all_keys_to_snake_case(dct: dict[str, Any]) -> dict[str, Any]:
     return dict(zip(map(to_snake_case, dct.keys()), dct.values()))
 
 
-def convert_dict_to_case(dct: Dict[str, Any], camel_case: bool) -> Dict[str, Any]:
+def convert_dict_to_case(dct: dict[str, Any], camel_case: bool) -> dict[str, Any]:
     if camel_case:
         return convert_all_keys_to_camel_case(dct)
     return convert_all_keys_to_snake_case(dct)
